@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from InstantMessage import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestIMAVManagerHelper (NSObject):
     def getPixelBufferPixelFormat_(self, _):
         return 10
@@ -47,9 +42,7 @@ class TestIMAVManager (TestCase):
         self.assertResultIsBOOL(TestIMAVManagerHelper.renderIntoPixelBuffer_forTime_)
         self.assertArgIsIn(TestIMAVManagerHelper.renderIntoPixelBuffer_forTime_, 1)
 
-
         self.assertResultIsBOOL(TestIMAVManagerHelper.renderIntoOpenGLBuffer_onScreen_forTime_)
 
-
 if __name__ == "__main__":
     main()
